@@ -1,7 +1,7 @@
-__version__ = '1.1.2'
+__version__ = '1.1.6'
 __title__ = 'openapi3-parser'
-__author__ = 'Artyom Manchenkov'
-__email__ = 'artyom@manchenkoff.me'
+__author__ = 'Artem Manchenkov'
+__email__ = 'artem@manchenkoff.me'
 __description__ = 'OpenAPI v3 parser'
 
 from .parser import parse
