@@ -1,7 +1,11 @@
+import logging
+
 from . import ContentBuilder
-from .common import PropertyMeta, extract_typed_props
+from .common import extract_typed_props, PropertyMeta
 from ..specification import RequestBody
 
+logger = logging.getLogger(__name__)
+
 
 class RequestBuilder:
     content_builder: ContentBuilder
@@ -10,8 +14,10 @@ class RequestBuilder:
         self.content_builder = content_builder
 
     def build(self, data: dict) -> RequestBody:
+        logger.debug(f"Request building")
+
         attrs_map = {
-            "content": PropertyMeta(name="content", cast=self.content_builder.build_collection),
+            "content": PropertyMeta(name="content", cast=self.content_builder.build_list),
             "description": PropertyMeta(name="description", cast=str),
             "required": PropertyMeta(name="required", cast=None),
         }
